==> kleopatra-16.04.0.tar.xz: kleopatra-16.04.0/src/utils/iodevicelogger.h <==
/* -*- mode: c++; c-basic-offset:4 -*-
    iodevicelogger.h

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2008 Klarälvdalens Datakonsult AB

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KLEOPATRA_IODEVICELOGGER_H__
#define __KLEOPATRA_IODEVICELOGGER_H__

#include <QIODevice>

#include <utils/pimpl_ptr.h>

#include <boost/shared_ptr.hpp>

namespace Kleo
{

class IODeviceLogger : public QIODevice
{
    Q_OBJECT
public:
    explicit IODeviceLogger(const boost::shared_ptr<QIODevice> &iod, QObject *parent = Q_NULLPTR);
    ~IODeviceLogger();

    void setWriteLogDevice(const boost::shared_ptr<QIODevice> &dev);
    void setReadLogDevice(const boost::shared_ptr<QIODevice> &dev);

    bool atEnd() const Q_DECL_OVERRIDE;
    qint64 bytesAvailable() const Q_DECL_OVERRIDE;
    qint64 bytesToWrite() const Q_DECL_OVERRIDE;
    bool canReadLine() const Q_DECL_OVERRIDE;
    void close() Q_DECL_OVERRIDE;
    bool isSequential() const Q_DECL_OVERRIDE;
    bool open(OpenMode mode) Q_DECL_OVERRIDE;
    qint64 pos() const Q_DECL_OVERRIDE;
    bool reset() Q_DECL_OVERRIDE;
    bool seek(qint64 pos) Q_DECL_OVERRIDE;
    qint64 size() const Q_DECL_OVERRIDE;
    bool waitForBytesWritten(int msecs) Q_DECL_OVERRIDE;
    bool waitForReadyRead(int msecs) Q_DECL_OVERRIDE;

protected:
    qint64 readData(char *data, qint64 maxSize) Q_DECL_OVERRIDE;
    qint64 writeData(const char *data, qint64 maxSize) Q_DECL_OVERRIDE;
    qint64 readLineData(char *data, qint64 maxSize) Q_DECL_OVERRIDE;

private:
    class Private;
    kdtools::pimpl_ptr<Private> d;
};
}

#endif // __KLEOPATRA_IODEVICELOGGER_H__

==> kleopatra-16.11.80.tar.xz: kleopatra-16.11.80/src/utils/iodevicelogger.h <==
/* -*- mode: c++; c-basic-offset:4 -*-
    iodevicelogger.h

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2008 Klarälvdalens Datakonsult AB

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KLEOPATRA_IODEVICELOGGER_H__
#define __KLEOPATRA_IODEVICELOGGER_H__

#include <QIODevice>

#include <utils/pimpl_ptr.h>

#include <memory>

namespace Kleo
{

class IODeviceLogger : public QIODevice
{
    Q_OBJECT
public:
    explicit IODeviceLogger(const std::shared_ptr<QIODevice> &iod, QObject *parent = Q_NULLPTR);
    ~IODeviceLogger();

    void setWriteLogDevice(const std::shared_ptr<QIODevice> &dev);
    void setReadLogDevice(const std::shared_ptr<QIODevice> &dev);

    bool atEnd() const Q_DECL_OVERRIDE;
    qint64 bytesAvailable() const Q_DECL_OVERRIDE;
    qint64 bytesToWrite() const Q_DECL_OVERRIDE;
    bool canReadLine() const Q_DECL_OVERRIDE;
    void close() Q_DECL_OVERRIDE;
    bool isSequential() const Q_DECL_OVERRIDE;
    bool open(OpenMode mode) Q_DECL_OVERRIDE;
    qint64 pos() const Q_DECL_OVERRIDE;
    bool reset() Q_DECL_OVERRIDE;
    bool seek(qint64 pos) Q_DECL_OVERRIDE;
    qint64 size() const Q_DECL_OVERRIDE;
    bool waitForBytesWritten(int msecs) Q_DECL_OVERRIDE;
    bool waitForReadyRead(int msecs) Q_DECL_OVERRIDE;

protected:
    qint64 readData(char *data, qint64 maxSize) Q_DECL_OVERRIDE;
    qint64 writeData(const char *data, qint64 maxSize) Q_DECL_OVERRIDE;
    qint64 readLineData(char *data, qint64 maxSize) Q_DECL_OVERRIDE;

private:
    class Private;
    kdtools::pimpl_ptr<Private> d;
};
}

#endif // __KLEOPATRA_IODEVICELOGGER_H__
